Type: Package
Package: decoupleR
Title: decoupleR: Ensemble of computational methods to infer biological
        activities from omics data
Version: 2.12.0
Authors@R: 
    c(person(given = "Pau",
             family = "Badia-i-Mompel",
             role = c("aut","cre"),
             email = "pau.badia@uni-heidelberg.de",
             comment = c(ORCID = "0000-0002-1004-3923")),
      person(given = "Jesús",
             family = "Vélez-Santiago",
             role = c("aut"),
             email = "jvelezmagic@gmail.com",
             comment = c(ORCID = "0000-0001-5128-3838")),
      person(given = "Jana",
             family = "Braunger",
             role = c("aut"),
             email = "jana.bc@gmx.de",
             comment = c(ORCID = "0000-0003-0820-9987")),
      person(given = "Celina",
             family = "Geiss",
             role = c("aut"),
             email = "celina.geiss@stud.uni-heidelberg.de",
             comment = c(ORCID = "0000-0002-8740-706X")),
      person(given = "Daniel",
             family = "Dimitrov",
             role = c("aut"),
             email = "daniel.dimitrov@uni-heidelberg.de",
             comment = c(ORCID = "0000-0002-5197-2112")),
      person(given = "Sophia",
             family = "Müller-Dott",
             role = c("aut"),
             email = "sophia.mueller-dott@uni-heidelberg.de",
             comment = c(ORCID = "0000-0002-9710-1865")),
      person(given = "Petr",
             family = "Taus",
             role = c("aut"),
             email = "petr.taus@ceitec.muni.cz",
             comment = c(ORCID = "0000-0003-3764-9033")),
      person(given = "Aurélien",
             family = "Dugourd",
             role = c("aut"),
             email = "aurelien.dugourd@bioquant.uni-heidelberg.de",
             comment = c(ORCID = "0000-0002-0714-028X")),
      person(given = "Christian H.",
             family = "Holland",
             role = "aut",
             email = "cholland2408@gmail.com",
             comment = c(ORCID = "0000-0002-3060-5786")),
      person(given = "Ricardo O.",
             family = "Ramirez Flores",
             role = c("aut"),
             email = "roramirezf@uni-heidelberg.de ",
             comment = c(ORCID = "0000-0003-0087-371X")),
      person(given = "Julio",
             family = "Saez-Rodriguez",
             role = c("aut"),
             email = "pub.saez@uni-heidelberg.de",
             comment = c(ORCID = "0000-0002-8552-8976"))
             )
Description: Many methods allow us to extract biological activities from omics
    data using information from prior knowledge resources, reducing the
    dimensionality for increased statistical power and better interpretability.
    Here, we present decoupleR, a Bioconductor package containing different
    statistical methods to extract these signatures within a unified framework.
    decoupleR allows the user to flexibly test any method with any resource.
    It incorporates methods that take into account the sign and weight of
    network interactions. decoupleR can be used with any omic, as long as its
    features can be linked to a biological process based on prior knowledge.
    For example, in transcriptomics gene sets regulated by a transcription
    factor, or in phospho-proteomics phosphosites that are targeted by a kinase.
License: GPL-3 + file LICENSE
URL: https://saezlab.github.io/decoupleR/
BugReports: https://github.com/saezlab/decoupleR/issues
Depends: R (>= 4.0)
Imports: BiocParallel, broom, dplyr, magrittr, Matrix, parallelly,
        purrr, rlang, stats, stringr, tibble, tidyr, tidyselect, withr
Suggests: glmnet (>= 4.1-7), GSVA, viper, fgsea (>= 1.15.4), AUCell,
        SummarizedExperiment, rpart, ranger, BiocStyle, covr, knitr,
        pkgdown, RefManageR, rmarkdown, roxygen2, sessioninfo,
        pheatmap, testthat, OmnipathR, Seurat, ggplot2, ggrepel,
        patchwork, magick
VignetteBuilder: knitr
biocViews: DifferentialExpression, FunctionalGenomics, GeneExpression,
        GeneRegulation, Network, Software, StatisticalMethod,
        Transcription,
Config/testthat/edition: 3
Encoding: UTF-8
Roxygen: list(markdown = TRUE)
RoxygenNote: 7.3.0
git_url: https://git.bioconductor.org/packages/decoupleR
git_branch: RELEASE_3_20
git_last_commit: bc3245c
git_last_commit_date: 2024-10-29
Repository: Bioconductor 3.20
Date/Publication: 2024-10-29
NeedsCompilation: no
Packaged: 2024-10-30 00:20:26 UTC; biocbuild
Author: Pau Badia-i-Mompel [aut, cre] (<https://orcid.org/0000-0002-1004-3923>),
  Jesús Vélez-Santiago [aut] (<https://orcid.org/0000-0001-5128-3838>),
  Jana Braunger [aut] (<https://orcid.org/0000-0003-0820-9987>),
  Celina Geiss [aut] (<https://orcid.org/0000-0002-8740-706X>),
  Daniel Dimitrov [aut] (<https://orcid.org/0000-0002-5197-2112>),
  Sophia Müller-Dott [aut] (<https://orcid.org/0000-0002-9710-1865>),
  Petr Taus [aut] (<https://orcid.org/0000-0003-3764-9033>),
  Aurélien Dugourd [aut] (<https://orcid.org/0000-0002-0714-028X>),
  Christian H. Holland [aut] (<https://orcid.org/0000-0002-3060-5786>),
  Ricardo O. Ramirez Flores [aut]
    (<https://orcid.org/0000-0003-0087-371X>),
  Julio Saez-Rodriguez [aut] (<https://orcid.org/0000-0002-8552-8976>)
Maintainer: Pau Badia-i-Mompel <pau.badia@uni-heidelberg.de>
