#' Pipe operator
#'
#' See \code{magrittr::\link[magrittr:pipe]{\%>\%}} for details.
#'
#' @name %>%
#' @rdname pipe
#' @keywords internal
#' @export
#' @importFrom magrittr %>%
#' @usage lhs \%>\% rhs
#' @return Pipe an object forward into a function or call expression.
#' @examples
#' c(1, 2, 3) %>% sum()
#' @noMd
NULL
